@@ -32,7 +32,7 @@ class ServiceProvider:
         self.config_manager: ConfigManager = None
         self.module_finder: ModuleFinder = None
         self.binder: Injector = None
-        
+
         self.logger = ConsoleLogger()
         # self.logger = logging.getLogger('test')
         # process_info = Utils.get_process_info()
@@ -102,10 +102,11 @@ class ServiceProvider:
         )
         self.binder.bind(
             interface=ConfigManager,
-            to=self.config_manager
+            to=self.config_manager,
+            scope=singleton
         )
 
-        for config in self.config_manager.get_all():
+        for config in self.config_manager.get_all_type_configs():
             self.binder.bind(
                 interface=config.get("type"),
                 to=config.get("instance"),
