@@ -10,3 +10,5 @@ class ConnectorTypes(Enum):
     Kafka = 6
     MYSQL = 7
     Impala = 8
+    Soap = 9
+    SqLite = 10
