@@ -1,8 +1,8 @@
 import os
 import sqlite3
 
+from pdip.integrator.connection.domain.types.inmemory import InMemoryConnectionConfiguration
 from ...base import InMemoryConnector
-from .....domain.inmemory import InMemoryConnectionConfiguration
 
 
 class SqLiteConnector(InMemoryConnector):
